pub enum LayerType {
DefaultForMaster(String),
AssociatedWithMaster(String),
FreeFloating,
}Expand description
The type of a layer in relation to masters
Variants
DefaultForMaster(String)
A default layer for a master
AssociatedWithMaster(String)
A layer associated with a master but not the default
FreeFloating
A free-floating layer not associated with any master